@@ -158,24 +158,30 @@ void KCalcParserCoreTest::testParserCore_data()
     QTest::newRow("parenthesis test 16") << QS("ln(exp(100.45))") << 10 << QS("100.45");
     // random input test (these are inputs that generated errors on production
     // or variations of those )
-    QTest::newRow("production 1") << QS("8-3*2+1") << 10 << QS("3");
-    QTest::newRow("production 2") << QS("8-3*2-1") << 10 << QS("1");
-    QTest::newRow("production 3") << QS("8-(3*2)+1") << 10 << QS("3");
-    QTest::newRow("production 4") << QS("8-(3*2+1)+1") << 10 << QS("2");
-    QTest::newRow("production 5") << QS("8-3*2-1") << 10 << QS("1");
-    QTest::newRow("production 6") << QS("8-6-1") << 10 << QS("1");
-    QTest::newRow("production 7") << QS("10-1-1-1-1-1-1") << 10 << QS("4");
-    QTest::newRow("production 8") << QS("-10-1-1-1-1-1-1") << 10 << QS("-16");
-    QTest::newRow("production 9") << QS("--10-1+1-1+1-1+1") << 10 << QS("10");
-    QTest::newRow("production 10") << QS("--10-1+1-1+1-1+1/5") << 10 << QS("46/5");
-    QTest::newRow("production 11") << QS("8 - 7 mod 2 +1") << 10 << QS("8");
-    QTest::newRow("production 12") << QS("8-sin(90)-1") << 10 << QS("6");
-    QTest::newRow("production 13") << QS("8-sin(90)+1") << 10 << QS("8");
-    QTest::newRow("production 14") << QS("8-cos(0)sin(90)-1") << 10 << QS("6");
-    QTest::newRow("production 15") << QS("8-cos(0)sin(90)+1") << 10 << QS("8");
-    QTest::newRow("production 16") << QS("8-cos(90)sin(90)+1") << 10 << QS("9");
-    QTest::newRow("production 17") << QS("8-√4+1") << 10 << QS("7");
-    QTest::newRow("production 18") << QS("8-√4-1") << 10 << QS("5");
+    QTest::newRow("Minus (-) second to last test 1") << QS("8-3*2+1") << 10 << QS("3");
+    QTest::newRow("Minus (-) second to last test 2") << QS("8-3*2-1") << 10 << QS("1");
+    QTest::newRow("Minus (-) second to last test 3") << QS("8-(3*2)+1") << 10 << QS("3");
+    QTest::newRow("Minus (-) second to last test 4") << QS("8-(3*2+1)+1") << 10 << QS("2");
+    QTest::newRow("Minus (-) second to last test 5") << QS("8-3*2-1") << 10 << QS("1");
+    QTest::newRow("Minus (-) second to last test 6") << QS("8-6-1") << 10 << QS("1");
+    QTest::newRow("Minus (-) second to last test 7") << QS("10-1-1-1-1-1-1") << 10 << QS("4");
+    QTest::newRow("Minus (-) second to last test 8") << QS("-10-1-1-1-1-1-1") << 10 << QS("-16");
+    QTest::newRow("Minus (-) second to last test 9") << QS("--10-1+1-1+1-1+1") << 10 << QS("10");
+    QTest::newRow("Minus (-) second to last test 10") << QS("--10-1+1-1+1-1+1/5") << 10 << QS("46/5");
+    QTest::newRow("Minus (-) second to last test 11") << QS("8 - 7 mod 2 +1") << 10 << QS("8");
+    QTest::newRow("Minus (-) second to last test 12") << QS("8-sin(90)-1") << 10 << QS("6");
+    QTest::newRow("Minus (-) second to last test 13") << QS("8-sin(90)+1") << 10 << QS("8");
+    QTest::newRow("Minus (-) second to last test 14") << QS("8-cos(0)sin(90)-1") << 10 << QS("6");
+    QTest::newRow("Minus (-) second to last test 15") << QS("8-cos(0)sin(90)+1") << 10 << QS("8");
+    QTest::newRow("Minus (-) second to last test 16") << QS("8-cos(90)sin(90)+1") << 10 << QS("9");
+    QTest::newRow("Minus (-) second to last test 17") << QS("8-√4+1") << 10 << QS("7");
+    QTest::newRow("Minus (-) second to last test 18") << QS("8-√4-1") << 10 << QS("5");
+
+    QTest::newRow("Decimal without leading zero test 1") << QS(".5+.5") << 10 << QS("1");
+    QTest::newRow("Decimal without leading zero test 2") << QS(".5+5") << 10 << QS("5.5");
+    QTest::newRow("Decimal without leading zero test 3") << QS("5.5+0.5") << 10 << QS("6");
+    QTest::newRow("Decimal without leading zero test 4") << QS(".1") << 10 << QS("0.1");
+    QTest::newRow("Decimal without leading zero test 5") << QS("cos(.1)") << 10 << QS("0.999998476913");
 }
 
 void KCalcParserCoreTest::testParserCore()
@@ -184,9 +190,10 @@ void KCalcParserCoreTest::testParserCore()
     QFETCH(int, base);
     QFETCH(QString, expectedResult);
 
-    int parsing_result, calculation_result, errorIndex;
+    KCalcParser::ParsingResult parsing_result;
+    int calculation_result, errorIndex;
     parsing_result = parser.stringToTokenQueue(input, base, token_Queue_, errorIndex);
-    QCOMPARE(parsing_result, 0); // successful parsing
+    QCOMPARE_NE(parsing_result, KCalcParser::ParsingResult::INVALID_TOKEN); // successful parsing
 
     calculation_result = core.calculate(token_Queue_, errorIndex);
 
@@ -214,10 +221,11 @@ void KCalcParserCoreTest::testParserError()
     QFETCH(QString, input);
     QFETCH(int, expectedErrorIndex);
 
-    int parsing_result, errorIndex;
+    KCalcParser::ParsingResult parsing_result;
+    int errorIndex;
     parsing_result = parser.stringToTokenQueue(input, 10, token_Queue_, errorIndex);
 
-    QCOMPARE_NE(parsing_result, 0); // fail on parsing
+    QCOMPARE_EQ(parsing_result, KCalcParser::ParsingResult::INVALID_TOKEN); // fail on parsing
     QCOMPARE(errorIndex, expectedErrorIndex); // index indicating error position
 }
 
