@@ -120,6 +120,7 @@ private:
     bool event(QEvent *e) override;
     void updateGeometry();
     void setupMainActions();
+    void setupDisplay();
     void setupKeys();
     void setupNumberKeys();
     void setupRightKeypad();
@@ -143,6 +144,7 @@ private:
     void setBitsetLayoutActive(bool active);
 
     void updateDisplay(UpdateFlags flags);
+    void insertFunctionToInputDisplay(KCalcToken::TokenCode token);
     void insertToInputDisplay(KCalcToken::TokenCode token);
     void insertToInputDisplay(const QString &token);
     KCalcStatusBar *statusBar();
@@ -219,6 +221,7 @@ protected Q_SLOTS:
     void slotHyptoggled(bool flag);
     void slotConstclicked(int);
     void slotBackspaceclicked();
+    void slotInputChanged();
 
     void slotConstantToDisplay(const science_constant &const_chosen);
     void slotChooseScientificConst0(const science_constant &);
@@ -256,7 +259,10 @@ private:
     int angle_mode_; // angle modes for trigonometric values
     int base_mode_;
 
-    bool parsing_failure_, calculation_failure_;
+    KCalcParser::ParsingResult m_parsingResult;
+    bool parsing_failure_;
+    bool calculation_failure_;
+    CalcEngine::ResultCode calculation_result_code_;
     int input_error_index_;
     int calculation_error_token_index_;
     void inline handle_Parsing_Error_();
