@@ -17,11 +17,15 @@ public:
     ~KCalcInputDisplay() override;
 
     void insertToken(const QString &token);
+    void insertTokenFunction(const QString &token);
 
 public Q_SLOTS:
+    void reset();
+    void slotSetFunctionWrap();
     void slotSetOverwrite();
     void slotSetHardOverwrite();
     void slotClearOverwrite();
+    void slotClearFunctionWrap();
 
 Q_SIGNALS:
 
@@ -33,4 +37,5 @@ private Q_SLOTS:
 private:
     bool overwrite_;
     bool hard_overwrite_;
+    bool function_wrap_;
 };
